==> postgrest-0.5.0.0-27-armv7h.pkg.tar.xz: usr/share/haskell/register/postgrest.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: postgrest
version: 0.5.0.0
id: postgrest-0.5.0.0-DEYE9oCwSvILHMBUVNqBKt
key: postgrest-0.5.0.0-DEYE9oCwSvILHMBUVNqBKt
license: MIT
maintainer: cred+github@begriffs.com
author: Joe Nelson, Adam Baker
homepage: https://github.com/PostgREST/postgrest
synopsis: REST API for any Postgres database
description:
    Reads the schema of a PostgreSQL database and creates RESTful routes
    for the tables and views, supporting all HTTP verbs that security
    permits.
category: Web
abi: 9b8264222f535df3c6e6ba8542f4ef51
exposed: True
exposed-modules:
    PostgREST.ApiRequest PostgREST.App PostgREST.Auth PostgREST.Config
    PostgREST.DbRequestBuilder PostgREST.DbStructure PostgREST.Error
    PostgREST.Middleware PostgREST.OpenAPI PostgREST.Parsers
    PostgREST.QueryBuilder PostgREST.RangeQuery PostgREST.Types
hidden-modules: Paths_postgrest
import-dirs: /usr/lib/ghc-8.4.3/site-local/postgrest-0.5.0.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/postgrest-0.5.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/postgrest-0.5.0.0
hs-libraries: HSpostgrest-0.5.0.0-DEYE9oCwSvILHMBUVNqBKt
depends:
    aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL
    ansi-wl-pprint-0.6.8.2-LQZDE7SKgje91HGB8abfY4 base-4.11.1.0
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    cassava-0.5.1.0-5fbQA7dnccC7UUuH337s1B
    configurator-ng-0.0.0.1-AyhvKyP9Qao2ynanBy2Rbc containers-0.5.11.0
    contravariant-1.5-5VBqEYOPGpyDW8QIali4BA
    contravariant-extras-0.3.4-6KPikGErH6JFY1GxYeFsWF
    either-5.0.1-F0FA5TpOWP8L5u4g2WGA0o
    gitrev-1.3.1-I3rV26MPk8fH6eAgYo6ASC
    hasql-1.3.0.3-DZSA4mqoni43O4AiUKGqsK
    hasql-pool-0.5-FgytgGzc0IOGXmtoSqfcK8
    hasql-transaction-0.7-DGgeXuzl7IZDtfOYQHs86c
    heredoc-0.2.0.0-Aca6RcVoh8MB0pyn5losTR
    HTTP-4000.3.12-J48Q8MxYay11zWeCEr7oX0
    http-types-0.12.1-C6lpBNl8s0n56pfgsv3YNb
    insert-ordered-containers-0.2.1.0-GNfoRVrH08VAp7BwWglyRK
    interpolatedstring-perl6-1.0.0-1dCR26QCRd9BF82WamZsn3
    jose-0.7.0.0-AYqak29EIKo97rFJqb5X4k
    lens-4.17-4C4gMEkWPox35sMHxQ6P7t
    lens-aeson-1.0.2-JdgloaIoaIsJ9mjrx0U7H7
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    optparse-applicative-0.14.2.0-5kDvpaFLtQNB16vTZLs8dg
    parsec-3.1.13.0 protolude-0.2.2-EOgREkuBhfuIEro3wh4uS3
    Ranged-sets-0.3.0-IVqwPqonijmBiSQsuY7IQL
    regex-tdfa-1.2.3.1-az1JL7mhmZBLFmoReK21K
    scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl
    swagger2-2.2.2-3C0IsVVXH324OylZ35Kcdx text-1.2.3.0 time-1.8.0.2
    unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    wai-3.2.1.2-LYrgj5pDFEpLGOS1bmSP2u
    wai-cors-0.2.6-HJxGkuM48u35UylPLgZLdq
    wai-extra-3.0.24.2-L0mYJmzT1I8CTWVX2yMpXV
    wai-middleware-static-0.8.2-Fq9MmAiesOoPMSmZHEuzE
    cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ
abi-depends: aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL=912860ab3519756596367ddae154025c
             ansi-wl-pprint-0.6.8.2-LQZDE7SKgje91HGB8abfY4=d46a34a69558ad25fb56e0bfd9741e31
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             cassava-0.5.1.0-5fbQA7dnccC7UUuH337s1B=44e4a80a759074c5ec05937cc569a933
             configurator-ng-0.0.0.1-AyhvKyP9Qao2ynanBy2Rbc=009cd1fb70b3dd3d8dd49ccb097a1bd9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             contravariant-1.5-5VBqEYOPGpyDW8QIali4BA=02e9ed60b8864056c6af15ff76a262ef
             contravariant-extras-0.3.4-6KPikGErH6JFY1GxYeFsWF=b0320e129fae25e9c4c825b327d6cb2f
             either-5.0.1-F0FA5TpOWP8L5u4g2WGA0o=e82328ad6f5e605483eff3b6dc7b9970
             gitrev-1.3.1-I3rV26MPk8fH6eAgYo6ASC=dfadfabf13d3d9a6719171042287531b
             hasql-1.3.0.3-DZSA4mqoni43O4AiUKGqsK=a092775a1981887b4ce9e6fa84dec768
             hasql-pool-0.5-FgytgGzc0IOGXmtoSqfcK8=533f192269b54652d54fe0717a0fa523
             hasql-transaction-0.7-DGgeXuzl7IZDtfOYQHs86c=1d83052d252a1fa7c1308b9c505dbfd0
             heredoc-0.2.0.0-Aca6RcVoh8MB0pyn5losTR=b190746a16f282487a662da19c44cf13
             HTTP-4000.3.12-J48Q8MxYay11zWeCEr7oX0=696bd0cfb24ce3d8fde0f3e316431c16
             http-types-0.12.1-C6lpBNl8s0n56pfgsv3YNb=976aaa70f9b7212c24b31f28f22b380a
             insert-ordered-containers-0.2.1.0-GNfoRVrH08VAp7BwWglyRK=d087a72bb3abcc984e53f5ada267faf8
             interpolatedstring-perl6-1.0.0-1dCR26QCRd9BF82WamZsn3=2106ecebab43444e935d8c187af589d5
             jose-0.7.0.0-AYqak29EIKo97rFJqb5X4k=0f2001c2b08ab9a825c290309cfc752b
             lens-4.17-4C4gMEkWPox35sMHxQ6P7t=4cb9fc45e7308a0ad354f525c2839895
             lens-aeson-1.0.2-JdgloaIoaIsJ9mjrx0U7H7=72f9af39287f161ccbd2c8c7632c9903
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=4ea8f0efa7a1ade0af4e9ce0cffcff8c
             optparse-applicative-0.14.2.0-5kDvpaFLtQNB16vTZLs8dg=ae7f0ef22284c6d85efc629be435c88e
             parsec-3.1.13.0=3626e7cedd22de76a8b10339d955721a
             protolude-0.2.2-EOgREkuBhfuIEro3wh4uS3=18ed455f1a139902a7939fe781363764
             Ranged-sets-0.3.0-IVqwPqonijmBiSQsuY7IQL=9fb8fc4b1711a19c280f975a4fa4bd83
             regex-tdfa-1.2.3.1-az1JL7mhmZBLFmoReK21K=98feb6ae4c5e833326f77c1995f4743b
             scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl=15b9d897726264a79d0c84c8eea548d3
             swagger2-2.2.2-3C0IsVVXH324OylZ35Kcdx=eff0572ef57d4bdeb305431c0df3a47b
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa=81e1d2b217f05c2ba43642acf6d96f3b
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             wai-3.2.1.2-LYrgj5pDFEpLGOS1bmSP2u=d9fba6511abb80273dc6e619fc5c09ff
             wai-cors-0.2.6-HJxGkuM48u35UylPLgZLdq=fb3251ffa877ea2efa7ed63e00131a6e
             wai-extra-3.0.24.2-L0mYJmzT1I8CTWVX2yMpXV=6790b57ba4d9297212ede9007a76a9f7
             wai-middleware-static-0.8.2-Fq9MmAiesOoPMSmZHEuzE=1bba324552f743b7fbd1ddf38e7d6deb
             cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ=98943a44942d0f9eb24e49aaa7774a37
haddock-interfaces: /usr/share/doc/postgrest/html/postgrest.haddock
haddock-html: /usr/share/doc/postgrest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> postgrest-0.5.0.0-30-armv7h.pkg.tar.xz: usr/share/haskell/register/postgrest.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: postgrest
version: 0.5.0.0
id: postgrest-0.5.0.0-5J56n8fmeVy3J53geQCZdt
key: postgrest-0.5.0.0-5J56n8fmeVy3J53geQCZdt
license: MIT
maintainer: cred+github@begriffs.com
author: Joe Nelson, Adam Baker
homepage: https://github.com/PostgREST/postgrest
synopsis: REST API for any Postgres database
description:
    Reads the schema of a PostgreSQL database and creates RESTful routes
    for the tables and views, supporting all HTTP verbs that security
    permits.
category: Web
abi: 1072a339bd915eae79e9d2a11fcacda4
exposed: True
exposed-modules:
    PostgREST.ApiRequest PostgREST.App PostgREST.Auth PostgREST.Config
    PostgREST.DbRequestBuilder PostgREST.DbStructure PostgREST.Error
    PostgREST.Middleware PostgREST.OpenAPI PostgREST.Parsers
    PostgREST.QueryBuilder PostgREST.RangeQuery PostgREST.Types
hidden-modules: Paths_postgrest
import-dirs: /usr/lib/ghc-8.4.3/site-local/postgrest-0.5.0.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/postgrest-0.5.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/postgrest-0.5.0.0
hs-libraries: HSpostgrest-0.5.0.0-5J56n8fmeVy3J53geQCZdt
depends:
    aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL
    ansi-wl-pprint-0.6.8.2-LQZDE7SKgje91HGB8abfY4 base-4.11.1.0
    base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    cassava-0.5.1.0-5fbQA7dnccC7UUuH337s1B
    configurator-ng-0.0.0.1-AyhvKyP9Qao2ynanBy2Rbc containers-0.5.11.0
    contravariant-1.5-5VBqEYOPGpyDW8QIali4BA
    contravariant-extras-0.3.4-6KPikGErH6JFY1GxYeFsWF
    either-5.0.1-F0FA5TpOWP8L5u4g2WGA0o
    gitrev-1.3.1-I3rV26MPk8fH6eAgYo6ASC
    hasql-1.3.0.3-ne4qWkTIevJyDHcEyXIKP
    hasql-pool-0.5-BisKljDjCyAGO9tLqRtG2f
    hasql-transaction-0.7-AkH7ZR99cfL7yjIvPAFYJN
    heredoc-0.2.0.0-Aca6RcVoh8MB0pyn5losTR
    HTTP-4000.3.12-E6lpt7Z6IZBKZaFY2ATUaX
    http-types-0.12.1-C6lpBNl8s0n56pfgsv3YNb
    insert-ordered-containers-0.2.1.0-GNfoRVrH08VAp7BwWglyRK
    interpolatedstring-perl6-1.0.0-1dCR26QCRd9BF82WamZsn3
    jose-0.7.0.0-AYqak29EIKo97rFJqb5X4k
    lens-4.17-4C4gMEkWPox35sMHxQ6P7t
    lens-aeson-1.0.2-JdgloaIoaIsJ9mjrx0U7H7
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    optparse-applicative-0.14.2.0-5kDvpaFLtQNB16vTZLs8dg
    parsec-3.1.13.0 protolude-0.2.2-EOgREkuBhfuIEro3wh4uS3
    Ranged-sets-0.3.0-IVqwPqonijmBiSQsuY7IQL
    regex-tdfa-1.2.3.1-az1JL7mhmZBLFmoReK21K
    scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl
    swagger2-2.2.2-3C0IsVVXH324OylZ35Kcdx text-1.2.3.0 time-1.8.0.2
    unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    wai-3.2.1.2-LYrgj5pDFEpLGOS1bmSP2u
    wai-cors-0.2.6-HJxGkuM48u35UylPLgZLdq
    wai-extra-3.0.24.2-L0mYJmzT1I8CTWVX2yMpXV
    wai-middleware-static-0.8.2-Fq9MmAiesOoPMSmZHEuzE
    cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ
abi-depends: aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL=912860ab3519756596367ddae154025c
             ansi-wl-pprint-0.6.8.2-LQZDE7SKgje91HGB8abfY4=d46a34a69558ad25fb56e0bfd9741e31
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=65adc4f5f54a1c07291b4ebc49756c05
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             cassava-0.5.1.0-5fbQA7dnccC7UUuH337s1B=44e4a80a759074c5ec05937cc569a933
             configurator-ng-0.0.0.1-AyhvKyP9Qao2ynanBy2Rbc=009cd1fb70b3dd3d8dd49ccb097a1bd9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             contravariant-1.5-5VBqEYOPGpyDW8QIali4BA=02e9ed60b8864056c6af15ff76a262ef
             contravariant-extras-0.3.4-6KPikGErH6JFY1GxYeFsWF=b0320e129fae25e9c4c825b327d6cb2f
             either-5.0.1-F0FA5TpOWP8L5u4g2WGA0o=e82328ad6f5e605483eff3b6dc7b9970
             gitrev-1.3.1-I3rV26MPk8fH6eAgYo6ASC=dfadfabf13d3d9a6719171042287531b
             hasql-1.3.0.3-ne4qWkTIevJyDHcEyXIKP=961b19556a6485cf195bce340d01628a
             hasql-pool-0.5-BisKljDjCyAGO9tLqRtG2f=88701556cb98886c6ae69813bc6e151a
             hasql-transaction-0.7-AkH7ZR99cfL7yjIvPAFYJN=507dc114d3276ba1ae4649e7d7bc48af
             heredoc-0.2.0.0-Aca6RcVoh8MB0pyn5losTR=b190746a16f282487a662da19c44cf13
             HTTP-4000.3.12-E6lpt7Z6IZBKZaFY2ATUaX=66697fb9da8efe60661335605062d68b
             http-types-0.12.1-C6lpBNl8s0n56pfgsv3YNb=976aaa70f9b7212c24b31f28f22b380a
             insert-ordered-containers-0.2.1.0-GNfoRVrH08VAp7BwWglyRK=d087a72bb3abcc984e53f5ada267faf8
             interpolatedstring-perl6-1.0.0-1dCR26QCRd9BF82WamZsn3=2106ecebab43444e935d8c187af589d5
             jose-0.7.0.0-AYqak29EIKo97rFJqb5X4k=0f2001c2b08ab9a825c290309cfc752b
             lens-4.17-4C4gMEkWPox35sMHxQ6P7t=4cb9fc45e7308a0ad354f525c2839895
             lens-aeson-1.0.2-JdgloaIoaIsJ9mjrx0U7H7=72f9af39287f161ccbd2c8c7632c9903
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=4ea8f0efa7a1ade0af4e9ce0cffcff8c
             optparse-applicative-0.14.2.0-5kDvpaFLtQNB16vTZLs8dg=ae7f0ef22284c6d85efc629be435c88e
             parsec-3.1.13.0=3626e7cedd22de76a8b10339d955721a
             protolude-0.2.2-EOgREkuBhfuIEro3wh4uS3=18ed455f1a139902a7939fe781363764
             Ranged-sets-0.3.0-IVqwPqonijmBiSQsuY7IQL=9fb8fc4b1711a19c280f975a4fa4bd83
             regex-tdfa-1.2.3.1-az1JL7mhmZBLFmoReK21K=98feb6ae4c5e833326f77c1995f4743b
             scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl=15b9d897726264a79d0c84c8eea548d3
             swagger2-2.2.2-3C0IsVVXH324OylZ35Kcdx=eff0572ef57d4bdeb305431c0df3a47b
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             unordered-containers-0.2.9.0-HkLL4IW6wFT9NZ9Hv37TSa=81e1d2b217f05c2ba43642acf6d96f3b
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             wai-3.2.1.2-LYrgj5pDFEpLGOS1bmSP2u=d9fba6511abb80273dc6e619fc5c09ff
             wai-cors-0.2.6-HJxGkuM48u35UylPLgZLdq=fb3251ffa877ea2efa7ed63e00131a6e
             wai-extra-3.0.24.2-L0mYJmzT1I8CTWVX2yMpXV=6790b57ba4d9297212ede9007a76a9f7
             wai-middleware-static-0.8.2-Fq9MmAiesOoPMSmZHEuzE=1bba324552f743b7fbd1ddf38e7d6deb
             cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ=98943a44942d0f9eb24e49aaa7774a37
haddock-interfaces: /usr/share/doc/postgrest/html/postgrest.haddock
haddock-html: /usr/share/doc/postgrest/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
